@@ -550,7 +550,7 @@ def moc_time_correlation():
 
         plt.figure(figsize=(16, 8))
         for sc in instru.SCS:
-            plot_tseries(instru.physics_t, instru.moc_time_correlations[sc], label=sc)
+            plot_tseries(instru.telemetry_t, instru.moc_time_correlations[sc], label=sc)
         plt.ylabel('Time [s]')
         plt.title('MOC time correlation noise')
         plt.legend()
@@ -559,7 +559,7 @@ def moc_time_correlation():
 
         plt.figure(figsize=(16, 8))
         for sc in instru.SCS:
-            plot_asd(instru.physics_t, instru.moc_time_correlations[sc], label=sc)
+            plot_asd(instru.telemetry_t, instru.moc_time_correlations[sc], label=sc)
         plt.ylabel('ASD [s/sqrt(Hz)]')
         plt.title('MOC time correlation noise')
         plt.legend()
@@ -742,12 +742,12 @@ def plot_measurements(instru, pdf):
     pdf.savefig()
     plt.close()
 
-    # Time-domain TCB timer deviations
+    # Time-domain MOC time correlations
     plt.figure(figsize=(16, 8))
     for sc in instru.SCS:
-        plot_tseries(instru.t, instru.tcb_timer_deviations[sc], skip=0, label=sc)
-    plt.ylabel('Timer deviation [s]')
-    plt.title('Timer deviations from TCB')
+        plot_tseries(instru.telemetry_t, instru.moc_time_correlations[sc], skip=0, label=sc)
+    plt.ylabel('Deviation [s]')
+    plt.title('MOC time correlations')
     plt.legend()
     pdf.savefig()
     plt.close()
